distance
========

Editop
-------
.. autoclass:: rapidfuzz.distance.Editop
    :members:

Editops
-------
.. autoclass:: rapidfuzz.distance.Editops
    :members:

Opcode
-------
.. autoclass:: rapidfuzz.distance.Opcode
    :members:

Opcodes
-------
.. autoclass:: rapidfuzz.distance.Opcodes
    :members:

.. toctree::
   :maxdepth: 1

   DamerauLevenshtein
   Hamming
   Indel
   Jaro
   JaroWinkler
   Levenshtein
   LCSseq
   OSA
   Prefix
   Postfix
